#!/bin/bash

set -e

exit_code=0

interface="$1"
if [ -z "$interface" ]; then
    echo "Error: Interface parameter not set" > /dev/stderr
    exit 1
fi

use_dhcp="$2"
if [ -z "$use_dhcp" ]; then
    echo "Error: Use DHCP parameter not set" > /dev/stderr
    exit 1
fi

dns_mode="$3"
if [ -z "$dns_mode" ]; then
    echo "Error: DNS Mode parameter not set" > /dev/stderr
    exit 1
fi

# The parameters below are optional
address="$4"
if [ ! -z "$address" ]; then
    # An address can't be set without netmask
    netmask="$5"
    if [ -z "$netmask" ]; then
        echo "Error: Netmask parameter not set" > /dev/stderr
        exit 1
    fi
fi
gateway="$6"
dns_nameservers="$7"

if [ "x$interface" = "xwan" ]; then
    interface_name="$RCT_WAN_IFACE"
elif [ "x$interface" = "xlan" ]; then
    interface_name="$RCT_LAN_IFACE"
else
    echo "Error: Incorrect interface parameter value: $interface" > /dev/stderr
    exit 1
fi

if [ ! -z "$gateway" ]; then
    gw_option_string="gateway $gateway"
fi

if [ "x$dns_mode" != "xdhcp" ]; then
    [ -z "$dns_nameservers" ] || \
        dns_option_sting="dns-nameservers $dns_nameservers"
fi

netconfig_save()
{
    mkdir -p "/tmp/rct/network/"
    cp -rf /etc/network/interfaces.d/ "/tmp/rct/network/"
    cp -f /etc/resolv.conf "/tmp/rct/network/"
    cp -f "/var/lib/rct/cache/${interface}.options" "/tmp/rct/network/"
}

netconfig_restore()
{
    if [ -d "/tmp/rct/network/" ]; then
        cp -rf "/tmp/rct/network/interfaces.d/" /etc/network/
        cp -f  "/tmp/rct/network/resolv.conf" /etc/resolv.conf
        cp -f  "/tmp/rct/network/${interface}.options" "/var/lib/rct/cache/"
    fi
}

netconfig_prepare()
{
    echo "dns_mode: $dns_mode" > "/var/lib/rct/cache/${interface}.options"
    echo "use_dhcp: $use_dhcp" >> "/var/lib/rct/cache/${interface}.options"

    if [ "x$use_dhcp" = "xfalse" ]; then
        cat << EOF > "/etc/network/interfaces.d/${interface}"
auto $interface_name
iface $interface_name inet static
    address $address
    netmask $netmask
    $gw_option_string
    $dns_option_sting
EOF
    else
        cat << EOF > "/etc/network/interfaces.d/${interface}"
auto $interface_name
iface $interface_name inet dhcp
    $dns_option_sting
EOF
    fi
}

netconfig_probe()
{
    systemctl stop networking
    netconfig_prepare
    systemctl start networking
}

netconfig_apply()
{
    systemctl stop networking
    ip address flush dev ${interface_name} permanent
    systemctl start networking
}

netconfig_save
if ! netconfig_probe; then
    echo "Error: Can't configure '${interface}' interface" > /dev/stderr
    exit_code=1
else
    (sleep 5; netconfig_prepare; netconfig_apply) &
fi

netconfig_restore
netconfig_apply

exit $exit_code
