#!/bin/bash

set -x
set +e

images="$(docker images --format '{{.Repository}}:{{.Tag}}' | \
    grep ":${RELEASE_TAG}")"

# Re-tagging old images so they don't become untagged
for old in $images; do
    base="$(basename $old | cut -f1- -d'-')"
    package="${base%%:*}"
    tag="$(docker run --rm "$old" apt-cache policy "$package" | \
        grep Installed | awk '{print $2}')"
    new="${old%%:*}:${tag}"
    docker tag "$old" "$new"
done

set -e

configs="-f /var/lib/rct/cache/docker-compose.yml"
if [ -f "/var/lib/rct/cache/docker-compose.${RELEASE_TAG}.yml" ]; then
    configs="$configs -f /var/lib/rct/cache/docker-compose.${RELEASE_TAG}.yml"
fi

docker-compose $configs pull
docker-compose $configs stop
docker-compose $configs down
docker-compose $configs up -d --force-recreate
