#!/bin/sh

set +e

tempdir="$(mktemp -d)"
dumpfile="/tmp/rct/devinfo-$(date +'%y%m%d%H%M%S').tar.gz"
trap "rm -rf $tempdir $dumpfile; exit 1" INT TERM PIPE KILL

configs="-f /var/lib/rct/cache/docker-compose.yml"
if [ -f "/var/lib/rct/cache/docker-compose.${RELEASE_TAG}.yml" ]; then
    configs="$configs -f /var/lib/rct/cache/docker-compose.${RELEASE_TAG}.yml"
fi

# Get system information
/bin/sh /usr/share/rct/actions/get_service_version.sh > \
    ${tempdir}/get_service_version.log

/bin/sh /usr/share/rct/actions/get_disk_state.sh > \
    ${tempdir}/get_disk_state.log

/bin/sh /usr/share/rct/actions/get_memory_state.sh > \
    ${tempdir}/get_memory_state.log

/bin/sh /usr/share/rct/actions/get_license_files_list.sh > \
    ${tempdir}/get_license_files_list.log

# Get docker services
docker ps -a --format {{.Names}}:{{.ID}}:{{.State}}:{{.Status}} > \
    ${tempdir}/docker-services.log

docker images --format '{{.Repository}}:{{.ID}}:{{.Tag}}' > \
    ${tempdir}/docker-images.log


# Get docker services log
docker-compose $configs logs --no-color --tail="all" > \
    ${tempdir}/docker-services-output.log

# Get network state
$(which ip) a > ${tempdir}/network-state.log
$(which ip) r >> ${tempdir}/network-state.log

# Get configuration and log files
cp -rf /etc ${tempdir}/
cp -rf /var/log/syslog /var/log/dmesg /var/log/rct/ ${tempdir}/
cp -rf /var/lib/rct/cache ${tempdir}/

# Get radar traffic dumps for the last 24 hours
mkdir -p ${tempdir}/cache/radar-dumps
find /var/lib/docker/volumes/ -name "*.eth" -mtime -1 \
    -exec cp {} ${tempdir}/cache/radar-dumps \;

# Compress the directory
tar -zcf $dumpfile $tempdir
rm -rf $tempdir

echo "$dumpfile" 1>&2
