#!/bin/bash

set -e

interface="$1"

if [ "x$interface" = "xwan" ]; then
    interface_name="$RCT_WAN_IFACE"
elif [ "x$interface" = "xlan" ]; then
    interface_name="$RCT_LAN_IFACE"
else
    echo "Error: Incorrect interface parameter value: $interface"
    exit 1
fi

if [ -z "$interface_name" ]; then
    echo "Error: Incorrect interface parameter value: $interface"
    exit 1
fi

cat "/var/lib/rct/cache/${interface}.options"
# Getting address
ip -o -f inet addr show "$interface_name" | \
    awk '{gsub(/\/[0-9]+/,"", $4); print "address: " $4}'

# Getting gateway
ip route show to default dev "$interface_name" | awk '{print "gateway: " $3}'

# Getting dns-nameservers
dns_nameservers="$(grep nameserver /etc/resolv.conf | grep -v '#' | \
    awk -vORS=', ' '{print $2}' | sed 's/, $/\n/')"
echo "dns_nameservers: $dns_nameservers"

# Getting broadcast
ip -o -f inet addr show "$interface_name" | awk '{print "broadcast: " $6}'

# Getting netmask
cidr_to_netmask()
{
    cidr=$1

    value=$(( 0xffffffff ^ ((1 << (32 - $cidr)) - 1) ))
    echo "$(( (value >> 24) & 0xff )).$(( (value >> 16) & 0xff )).$(( (value >> 8) & 0xff )).$(( value & 0xff ))"
}

cidr=$(ip -o -f inet addr show "$interface_name" | \
    awk '{gsub(/.*\//,"", $4); print $4}')

echo "netmask: $(cidr_to_netmask $cidr)"
